@@ -78,7 +78,7 @@ namespace Oxygen
             "(?:(\\d+),(\\d+),(\\d+)(?:,(\\d+))?)",
             G_REGEX_CASELESS, (GRegexMatchFlags)0, 0L );
 
-        GMatchInfo* matchInfo(0L);
+        GMatchInfo* matchInfo;
         g_regex_match( regex, value.c_str(), (GRegexMatchFlags)0, &matchInfo);
         const int matchCount( g_match_info_get_match_count( matchInfo ) );
         if( matchCount == 2 )
