@@ -38,11 +38,17 @@
 #include "oxygentaboptions.h"
 #include "oxygentileset.h"
 #include "oxygenwidgetlookup.h"
+#include "oxygenwidgetexplorer.h"
 #include "oxygenwindecooptions.h"
 #include "oxygenwindecobutton.h"
 #include "oxygenwindowmanager.h"
+
 #include <gdk/gdk.h>
 
+#ifdef GDK_WINDOWING_X11
+#include <X11/Xdefs.h>
+#endif
+
 namespace Oxygen
 {
 
@@ -97,6 +103,10 @@ namespace Oxygen
         ShadowHelper& shadowHelper( void )
         { return _shadowHelper; }
 
+        //! window manager
+        WidgetExplorer& widgetExplorer( void )
+        { return _widgetExplorer; }
+
         //! window manager
         WindowManager& windowManager( void )
         { return _windowManager; }
@@ -111,6 +121,9 @@ namespace Oxygen
         //! background surface
         bool hasBackgroundSurface( void ) const;
 
+        //! update kwin blur region
+        void setWindowBlur(GdkWindow* window,bool enable);
+
         //!@name primitives
         //@{
 
@@ -350,8 +363,7 @@ namespace Oxygen
         protected:
 
         //! constructor
-        explicit Style( void )
-        {}
+        Style( void );
 
         //! get color matching role from either style option or default palette
         const ColorUtils::Rgba& color( Palette::Role role, const StyleOptions& option ) const
@@ -500,6 +512,9 @@ namespace Oxygen
         //! shadow helper
         ShadowHelper _shadowHelper;
 
+        //! widget explorer
+        WidgetExplorer _widgetExplorer;
+
         //! window manager
         WindowManager _windowManager;
 
@@ -535,6 +550,11 @@ namespace Oxygen
         //! Tab close buttons
         TabCloseButtons _tabCloseButtons;
 
+        #ifdef GDK_WINDOWING_X11
+        //! Atom to show kwin what regions of translucent windows should be blurred
+        Atom _blurAtom;
+        #endif
+
         //! singleton
         static Style* _instance;
 
